mocks

package
v0.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 13, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCommandPort

type MockCommandPort struct {
	// contains filtered or unexported fields
}

MockCommandPort is a mock of CommandPort interface.

func NewMockCommandPort

func NewMockCommandPort(ctrl *gomock.Controller) *MockCommandPort

NewMockCommandPort creates a new mock instance.

func (*MockCommandPort) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCommandPort) GetStdin

func (m *MockCommandPort) GetStdin() io.WriteCloser

GetStdin mocks base method.

func (*MockCommandPort) GetStdout

func (m *MockCommandPort) GetStdout() io.ReadCloser

GetStdout mocks base method.

func (*MockCommandPort) IsRunning

func (m *MockCommandPort) IsRunning() bool

IsRunning mocks base method.

func (*MockCommandPort) Start

func (m *MockCommandPort) Start() error

Start mocks base method.

func (*MockCommandPort) Stop

func (m *MockCommandPort) Stop() error

Stop mocks base method.

type MockCommandPortFactory

type MockCommandPortFactory struct {
	// contains filtered or unexported fields
}

MockCommandPortFactory is a mock of CommandPortFactory interface.

func NewMockCommandPortFactory

func NewMockCommandPortFactory(ctrl *gomock.Controller) *MockCommandPortFactory

NewMockCommandPortFactory creates a new mock instance.

func (*MockCommandPortFactory) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCommandPortFactory) NewCommandPort

func (m *MockCommandPortFactory) NewCommandPort(command string, args ...string) (command_port.CommandPort, error)

NewCommandPort mocks base method.

type MockCommandPortFactoryMockRecorder

type MockCommandPortFactoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockCommandPortFactoryMockRecorder is the mock recorder for MockCommandPortFactory.

func (*MockCommandPortFactoryMockRecorder) NewCommandPort

func (mr *MockCommandPortFactoryMockRecorder) NewCommandPort(command any, args ...any) *gomock.Call

NewCommandPort indicates an expected call of NewCommandPort.

type MockCommandPortMockRecorder

type MockCommandPortMockRecorder struct {
	// contains filtered or unexported fields
}

MockCommandPortMockRecorder is the mock recorder for MockCommandPort.

func (*MockCommandPortMockRecorder) GetStdin

func (mr *MockCommandPortMockRecorder) GetStdin() *gomock.Call

GetStdin indicates an expected call of GetStdin.

func (*MockCommandPortMockRecorder) GetStdout

func (mr *MockCommandPortMockRecorder) GetStdout() *gomock.Call

GetStdout indicates an expected call of GetStdout.

func (*MockCommandPortMockRecorder) IsRunning

func (mr *MockCommandPortMockRecorder) IsRunning() *gomock.Call

IsRunning indicates an expected call of IsRunning.

func (*MockCommandPortMockRecorder) Start

Start indicates an expected call of Start.

func (*MockCommandPortMockRecorder) Stop

Stop indicates an expected call of Stop.

type MockTimeoutProxy

type MockTimeoutProxy struct {
	// contains filtered or unexported fields
}

MockTimeoutProxy is a mock of TimeoutProxy interface.

func NewMockTimeoutProxy

func NewMockTimeoutProxy(ctrl *gomock.Controller) *MockTimeoutProxy

NewMockTimeoutProxy creates a new mock instance.

func (*MockTimeoutProxy) Close

func (m *MockTimeoutProxy) Close() error

Close mocks base method.

func (*MockTimeoutProxy) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTimeoutProxy) GetTimeout

func (m *MockTimeoutProxy) GetTimeout() time.Duration

GetTimeout mocks base method.

func (*MockTimeoutProxy) HandleMessage

func (m *MockTimeoutProxy) HandleMessage(msg entities.JSONRPCMessage) error

HandleMessage mocks base method.

func (*MockTimeoutProxy) Run

func (m *MockTimeoutProxy) Run() error

Run mocks base method.

type MockTimeoutProxyFactory

type MockTimeoutProxyFactory struct {
	// contains filtered or unexported fields
}

MockTimeoutProxyFactory is a mock of TimeoutProxyFactory interface.

func NewMockTimeoutProxyFactory

func NewMockTimeoutProxyFactory(ctrl *gomock.Controller) *MockTimeoutProxyFactory

NewMockTimeoutProxyFactory creates a new mock instance.

func (*MockTimeoutProxyFactory) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTimeoutProxyFactory) NewTimeoutProxy

func (m *MockTimeoutProxyFactory) NewTimeoutProxy(timeout time.Duration, commandPort command_port.CommandPort) (timeout_port.TimeoutProxy, error)

NewTimeoutProxy mocks base method.

type MockTimeoutProxyFactoryMockRecorder

type MockTimeoutProxyFactoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockTimeoutProxyFactoryMockRecorder is the mock recorder for MockTimeoutProxyFactory.

func (*MockTimeoutProxyFactoryMockRecorder) NewTimeoutProxy

func (mr *MockTimeoutProxyFactoryMockRecorder) NewTimeoutProxy(timeout, commandPort any) *gomock.Call

NewTimeoutProxy indicates an expected call of NewTimeoutProxy.

type MockTimeoutProxyMockRecorder

type MockTimeoutProxyMockRecorder struct {
	// contains filtered or unexported fields
}

MockTimeoutProxyMockRecorder is the mock recorder for MockTimeoutProxy.

func (*MockTimeoutProxyMockRecorder) Close

Close indicates an expected call of Close.

func (*MockTimeoutProxyMockRecorder) GetTimeout

func (mr *MockTimeoutProxyMockRecorder) GetTimeout() *gomock.Call

GetTimeout indicates an expected call of GetTimeout.

func (*MockTimeoutProxyMockRecorder) HandleMessage

func (mr *MockTimeoutProxyMockRecorder) HandleMessage(msg any) *gomock.Call

HandleMessage indicates an expected call of HandleMessage.

func (*MockTimeoutProxyMockRecorder) Run

Run indicates an expected call of Run.

Jump to